package org.apidesign.apifest08.currency;

import java.util.Currency;
import java.util.Hashtable;
import java.util.Map;

/** This is the skeleton class for your API. You need to make it public, so
 * it is accessible to your client code (currently in Task1Test.java) file.
 * <p>
 * Feel free to create additional classes or rename this one, just keep all
 * the API and its implementation in this package. Do not spread it outside
 * to other packages.
 */
public class Convertor {
    
    private static final Map<String, Float> EXCHANGE_RATES = new Hashtable<String, Float>() { {
            put("CZKUSD", 1/17F);
            put("USDCZK", 17F);
            put("SKKCZK", 100/80F);
            put("CZKSKK", 80/100F);
        }
    };
    
    private Currency currencyFirst;
    private Currency currencySecond;
    
    private Convertor(Currency currencyFirst, Currency currencySecond) {
        this.currencyFirst = currencyFirst;
        this.currencySecond = currencySecond;
    }
    
    public static Convertor getInstanceFor(Currency currencyFirst, Currency currencySecond) {
        return new Convertor(currencyFirst, currencySecond);
    }
    
    public float convert(float value, Currency toCurrency) {
        if (!toCurrency.equals(currencyFirst) && !toCurrency.equals(currencySecond)) {
            throw new IllegalArgumentException("Unsupported currency for this convertor!: " + toCurrency.getCurrencyCode());
        }
        
        Float rate = null;
        if (toCurrency.equals(currencyFirst)) {
            rate = EXCHANGE_RATES.get(currencyFirst.getCurrencyCode() + currencySecond.getCurrencyCode());
        }
        if (toCurrency.equals(currencySecond)) {
            rate = EXCHANGE_RATES.get(currencySecond.getCurrencyCode() + currencyFirst.getCurrencyCode());
        }

        if (rate == null) {
            throw new IllegalStateException("Undefinied conversion!");
        }

        return rate*value;
    }
}
